/**
 * A component that renders a popover for a selected/highlighted text.
 *
 * @remarks
 * The `react-highlight-popover` defines the {@link HighlightableTextAreaProps} interface and {@link HighlightableTextArea} function.
 *
 * @packageDocumentation
 */
import * as React from 'react';
import './styles.scss';
declare type popoverItemCallback = (text: string) => React.ReactNode;
declare type onHighlightTextCallback = (event: MouseEvent) => void;
/**
 * Defines the props for {@link HighlightableTextArea}
 */
export interface HighlightableTextAreaProps {
    /**
     * The item to be rendered as popover when user has selected/highlighted text.
     * It is a function that takes `text` as an argument and returns a react node.
     * @example
     * Here is how the format can be;
     *
     * ```ts
     * popoverItem={(text) => {
     *  return (
     *    <div>
     *      <p>{text}</p>
     *    </div>
     * )}}
     * ```
     */
    popoverItem?: popoverItemCallback;
    /**
     * This event is fired whenever user has selected/highlighted text.
     * It is a callback function that takes `event` as an argument.
     * @eventProperty
     */
    onHighlightText?: onHighlightTextCallback;
    /**
     * Positions the popover along the x-axis of the selected text.
     * @defaultValue 0
     */
    XOffset?: number;
    /**
     * Positions the popover along the y-axis of the selected text.
     * @defaultValue 10
     */
    YOffset?: number;
    children: React.ReactNode;
}
/**
 * Defines the area in which selected/highlighted text will render a popover.
 * @public
 */
export declare const HighlightableTextArea: ({ popoverItem, onHighlightText, XOffset, YOffset, children }: HighlightableTextAreaProps) => JSX.Element;
export {};
